Subcommands Example
====================

Example demonstrating how to implement command-line subcommands at the application layer
while using Varlord for configuration management.

.. literalinclude:: ../../../examples/subcommands_example.py
   :language: python
   :linenos:

